<template>
  <!-- 路障实时数据 -->
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-row :gutter="10">
          <el-col :span="12">
            <el-form-item label="采集时间">
              <el-date-picker v-model="querys[0].value" type="datetimerange" style="width: 100%"
                value-format="yyyy-MM-dd HH:mm:ss" range-separator="至" start-placeholder="开始日期" end-placeholder="结束日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item>
              <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
              </el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">重置
              </el-button>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel"></div>
      <el-table border size="mini" :data="tableData" :height="tableMaxHeight - 10" :style="{ width: '100%' }"
        :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
        @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="120" prop="deviceCode" label="设备标识" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="120" prop="collTime" label="采集时间" show-overflow-tooltip>
        </el-table-column>
        <el-table-column prop="memo" label="采集对象" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="120" prop="sdata" label="气体浓度" show-overflow-tooltip>
        </el-table-column>
        <!-- <el-table-column min-width="140"  prop="voltage" label="设备电压(单位：V)" show-overflow-tooltip>
</el-table-column> -->
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
        @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
        :total="total"></el-pagination>
    </div>
  </div>
</template>

<script>
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
import equipmentManage from '@/api/device/equipmentManage.js'
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'RealTimeData',
  mixins: [TableMixin],
  props: {
    parameter: {
      type: Object,
      default: function () {
        return
      }
    }
  },
  data() {
    return {
      productParams: {},
      productType: {},
      realData: [],
      productTypelx: '',
      dataTypeList: [], //数据类型字典
      actionList: [], //动作标识字典
      statusList: [], //成功状态字典
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'b.coll_time_',
          relation: 'AND',
          value: ''
        }
      ],
      sorter: [
        {
          direction: 'DESC',
          property: 'collTime'
        }
      ]
    }
  },
  created() {
    this.getProduct()
  },
  mounted() {
  },
  methods: {
    calcTableHeight(delay) {
      // 动态计算表格的高度，自适应当前容器
      setTimeout(() => {
        this.$nextTick(() => {
          if (!this.$refs.contentPanel) {
            return
          }
          const contentPanelHeight = (this.$refs.contentPanel && this.$refs.contentPanel.clientHeight) || 0
          const btnPanelHeight = (this.$refs.btnPanel && this.$refs.btnPanel.clientHeight) || 0
          const paginationPanelHeight = this.$refs.paginationPanel ? 32 : 0
          // (this.$refs.paginationPanel &&
          //     this.$refs.paginationPanel.clientHeight) ||
          // 0;
          this.tableMaxHeight =
            contentPanelHeight -
            btnPanelHeight -
            paginationPanelHeight - 42
        })

      }, delay || 0)
    },

    handleUpdate(row) {
      console.log(row)
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
    },
    getProduct() {
      productManage
        .productInfoDetail(this.parameter.productId)
        .then((res) => {
          this.productParams = res
          productManage
            .productTypeDetail(this.productParams.typeId)
            .then((res) => {
              this.productType = res
              //   this.loadData()
            })
        })
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam = Object.assign(this.queryParam, {
        sorter: this.sorter
      })
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      let protal = window.context.portal
      let requestData = {
        url: `${protal}/device/data/query?id=` + this.parameter.id,
        data: this.queryParam,
        method: 'post'
      }
      // 根据设备id获取实时数据
      req.request(requestData)
        .then((res) => {
          console.log(res)
          if (res.status) {
            this.productTypelx = res.data.value.productType
            this.tableData = res.data.value.data.rows
            this.total = res.data.value.data.total
            this.$set(this.tableData)
            this.loading = false
          }
        })
        .catch((err) => {
          console.log(err)
        })
    }
  }
}
</script>

<style lang="scss" scoped>
::v-deep .bbsl-table-search {
  height: 50px;
}

::v-deep .bbsl-btn-content {
  margin-bottom: 0;
}

::v-deep .el-table {
  height: 100% !important;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}

.bbsl-common-page {
  height: 100%;
}

.bbsl-table-content {
  position: relative;

  ::v-deep .el-pagination {
    position: absolute;
    right: 10px;
    bottom: 10px;
  }
}
</style>
